export declare type Chunk = {
    highlight: boolean;
    start: number;
    end: number;
    className?: string;
    key?: number;
    value?: string;
};
/**
 *
 * @param string
 */
declare function defaultSanitize(string: string): string;
/**
 * 对所有切割的模块进行同类交叉、异类交叉、异类包含处理
 * @return {Chunk[]}
 */
export declare const combineChunks: ({ chunks, }: {
    chunks: Array<Chunk>;
}) => Array<Chunk>;
/**
 *
 * 处理words的中多组数据并合并在一起，然后交个combineChunks, combineChunks会利用其下标重新排序
 * @return {start:number, end:number, className: string}[]
 */
declare const defaultFindChunks: ({ words, activeClasses, ...rest }: {
    autoEscape?: boolean | undefined;
    caseSensitive?: boolean | undefined;
    sanitize?: typeof defaultSanitize | undefined;
    textToHighlight: string;
    words: Array<string | Array<string>>;
    activeClasses: Array<string>;
}) => Array<Chunk>;
export { defaultFindChunks as findChunks };
/**
 * 将原文本拆成包含需要高亮和不需要高亮的全部模块
 * @param chunksToHighlight 所有处理之后需要高亮的模块
 * @param totalLength number
 * @return {start:number, end:number, highlight:boolean, className: string}[]
 */
export declare const fillInChunks: ({ chunksToHighlight, totalLength }: {
    chunksToHighlight: Array<Chunk>;
    totalLength: number;
}) => Array<Chunk>;
export interface FindAllChunksProps {
    autoEscape?: boolean;
    caseSensitive?: boolean;
    findChunks?: typeof defaultFindChunks;
    sanitize?: typeof defaultSanitize;
    words: Array<Array<string> | string>;
    activeClasses: Array<string>;
    textToHighlight: string;
}
/**
 * @return 返回所有的chunks,包括高亮和不需要高亮全部 { start:number, end:number, highlight:boolean, className: string })
 */
export declare const findAll: ({ autoEscape, caseSensitive, findChunks, sanitize, textToHighlight, words, activeClasses, }: FindAllChunksProps) => Array<Chunk>;
